thingy52 package
================

Submodules
----------

thingy52.thingy52 module
------------------------

.. automodule:: thingy52.thingy52
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: thingy52
    :members:
    :undoc-members:
    :show-inheritance:
